# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateVbInstanceDetails(object):
    """
    The information about new VbInstance.
    """

    #: A constant which can be used with the consumption_model property of a CreateVbInstanceDetails.
    #: This constant has a value of "UCM"
    CONSUMPTION_MODEL_UCM = "UCM"

    #: A constant which can be used with the consumption_model property of a CreateVbInstanceDetails.
    #: This constant has a value of "GOV"
    CONSUMPTION_MODEL_GOV = "GOV"

    #: A constant which can be used with the consumption_model property of a CreateVbInstanceDetails.
    #: This constant has a value of "VB4SAAS"
    CONSUMPTION_MODEL_VB4_SAAS = "VB4SAAS"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateVbInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateVbInstanceDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateVbInstanceDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateVbInstanceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateVbInstanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param idcs_open_id:
            The value to assign to the idcs_open_id property of this CreateVbInstanceDetails.
        :type idcs_open_id: str

        :param node_count:
            The value to assign to the node_count property of this CreateVbInstanceDetails.
        :type node_count: int

        :param is_visual_builder_enabled:
            The value to assign to the is_visual_builder_enabled property of this CreateVbInstanceDetails.
        :type is_visual_builder_enabled: bool

        :param custom_endpoint:
            The value to assign to the custom_endpoint property of this CreateVbInstanceDetails.
        :type custom_endpoint: oci.visual_builder.models.CreateCustomEndpointDetails

        :param alternate_custom_endpoints:
            The value to assign to the alternate_custom_endpoints property of this CreateVbInstanceDetails.
        :type alternate_custom_endpoints: list[oci.visual_builder.models.CreateCustomEndpointDetails]

        :param consumption_model:
            The value to assign to the consumption_model property of this CreateVbInstanceDetails.
            Allowed values for this property are: "UCM", "GOV", "VB4SAAS"
        :type consumption_model: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'idcs_open_id': 'str',
            'node_count': 'int',
            'is_visual_builder_enabled': 'bool',
            'custom_endpoint': 'CreateCustomEndpointDetails',
            'alternate_custom_endpoints': 'list[CreateCustomEndpointDetails]',
            'consumption_model': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'idcs_open_id': 'idcsOpenId',
            'node_count': 'nodeCount',
            'is_visual_builder_enabled': 'isVisualBuilderEnabled',
            'custom_endpoint': 'customEndpoint',
            'alternate_custom_endpoints': 'alternateCustomEndpoints',
            'consumption_model': 'consumptionModel'
        }

        self._display_name = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._idcs_open_id = None
        self._node_count = None
        self._is_visual_builder_enabled = None
        self._custom_endpoint = None
        self._alternate_custom_endpoints = None
        self._consumption_model = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateVbInstanceDetails.
        Vb Instance Identifier.


        :return: The display_name of this CreateVbInstanceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateVbInstanceDetails.
        Vb Instance Identifier.


        :param display_name: The display_name of this CreateVbInstanceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateVbInstanceDetails.
        Compartment Identifier.


        :return: The compartment_id of this CreateVbInstanceDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateVbInstanceDetails.
        Compartment Identifier.


        :param compartment_id: The compartment_id of this CreateVbInstanceDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateVbInstanceDetails.
        Simple key-value pair that is applied without any predefined name,
        type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateVbInstanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateVbInstanceDetails.
        Simple key-value pair that is applied without any predefined name,
        type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateVbInstanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateVbInstanceDetails.
        Usage of predefined tag keys. These predefined keys are scoped to
        namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateVbInstanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateVbInstanceDetails.
        Usage of predefined tag keys. These predefined keys are scoped to
        namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateVbInstanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def idcs_open_id(self):
        """
        Gets the idcs_open_id of this CreateVbInstanceDetails.
        Encrypted IDCS Open ID token. This is required for pre-UCPIS cloud accounts, but not UCPIS, hence not a required parameter


        :return: The idcs_open_id of this CreateVbInstanceDetails.
        :rtype: str
        """
        return self._idcs_open_id

    @idcs_open_id.setter
    def idcs_open_id(self, idcs_open_id):
        """
        Sets the idcs_open_id of this CreateVbInstanceDetails.
        Encrypted IDCS Open ID token. This is required for pre-UCPIS cloud accounts, but not UCPIS, hence not a required parameter


        :param idcs_open_id: The idcs_open_id of this CreateVbInstanceDetails.
        :type: str
        """
        self._idcs_open_id = idcs_open_id

    @property
    def node_count(self):
        """
        **[Required]** Gets the node_count of this CreateVbInstanceDetails.
        The number of Nodes


        :return: The node_count of this CreateVbInstanceDetails.
        :rtype: int
        """
        return self._node_count

    @node_count.setter
    def node_count(self, node_count):
        """
        Sets the node_count of this CreateVbInstanceDetails.
        The number of Nodes


        :param node_count: The node_count of this CreateVbInstanceDetails.
        :type: int
        """
        self._node_count = node_count

    @property
    def is_visual_builder_enabled(self):
        """
        Gets the is_visual_builder_enabled of this CreateVbInstanceDetails.
        Visual Builder is enabled or not.


        :return: The is_visual_builder_enabled of this CreateVbInstanceDetails.
        :rtype: bool
        """
        return self._is_visual_builder_enabled

    @is_visual_builder_enabled.setter
    def is_visual_builder_enabled(self, is_visual_builder_enabled):
        """
        Sets the is_visual_builder_enabled of this CreateVbInstanceDetails.
        Visual Builder is enabled or not.


        :param is_visual_builder_enabled: The is_visual_builder_enabled of this CreateVbInstanceDetails.
        :type: bool
        """
        self._is_visual_builder_enabled = is_visual_builder_enabled

    @property
    def custom_endpoint(self):
        """
        Gets the custom_endpoint of this CreateVbInstanceDetails.

        :return: The custom_endpoint of this CreateVbInstanceDetails.
        :rtype: oci.visual_builder.models.CreateCustomEndpointDetails
        """
        return self._custom_endpoint

    @custom_endpoint.setter
    def custom_endpoint(self, custom_endpoint):
        """
        Sets the custom_endpoint of this CreateVbInstanceDetails.

        :param custom_endpoint: The custom_endpoint of this CreateVbInstanceDetails.
        :type: oci.visual_builder.models.CreateCustomEndpointDetails
        """
        self._custom_endpoint = custom_endpoint

    @property
    def alternate_custom_endpoints(self):
        """
        Gets the alternate_custom_endpoints of this CreateVbInstanceDetails.
        A list of alternate custom endpoints to be used for the vb instance URL
        (contact Oracle for alternateCustomEndpoints availability for a specific instance).


        :return: The alternate_custom_endpoints of this CreateVbInstanceDetails.
        :rtype: list[oci.visual_builder.models.CreateCustomEndpointDetails]
        """
        return self._alternate_custom_endpoints

    @alternate_custom_endpoints.setter
    def alternate_custom_endpoints(self, alternate_custom_endpoints):
        """
        Sets the alternate_custom_endpoints of this CreateVbInstanceDetails.
        A list of alternate custom endpoints to be used for the vb instance URL
        (contact Oracle for alternateCustomEndpoints availability for a specific instance).


        :param alternate_custom_endpoints: The alternate_custom_endpoints of this CreateVbInstanceDetails.
        :type: list[oci.visual_builder.models.CreateCustomEndpointDetails]
        """
        self._alternate_custom_endpoints = alternate_custom_endpoints

    @property
    def consumption_model(self):
        """
        Gets the consumption_model of this CreateVbInstanceDetails.
        Optional parameter specifying which entitlement to use for billing purposes. Only required if the account possesses more than one entitlement.

        Allowed values for this property are: "UCM", "GOV", "VB4SAAS"


        :return: The consumption_model of this CreateVbInstanceDetails.
        :rtype: str
        """
        return self._consumption_model

    @consumption_model.setter
    def consumption_model(self, consumption_model):
        """
        Sets the consumption_model of this CreateVbInstanceDetails.
        Optional parameter specifying which entitlement to use for billing purposes. Only required if the account possesses more than one entitlement.


        :param consumption_model: The consumption_model of this CreateVbInstanceDetails.
        :type: str
        """
        allowed_values = ["UCM", "GOV", "VB4SAAS"]
        if not value_allowed_none_or_none_sentinel(consumption_model, allowed_values):
            raise ValueError(
                "Invalid value for `consumption_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._consumption_model = consumption_model

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModuleStreamProfileOnManagedInstanceSummary(object):
    """
    Summary information pertaining to a module stream profile on a managed instance
    """

    #: A constant which can be used with the status property of a ModuleStreamProfileOnManagedInstanceSummary.
    #: This constant has a value of "INSTALLED"
    STATUS_INSTALLED = "INSTALLED"

    #: A constant which can be used with the status property of a ModuleStreamProfileOnManagedInstanceSummary.
    #: This constant has a value of "AVAILABLE"
    STATUS_AVAILABLE = "AVAILABLE"

    def __init__(self, **kwargs):
        """
        Initializes a new ModuleStreamProfileOnManagedInstanceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param module_name:
            The value to assign to the module_name property of this ModuleStreamProfileOnManagedInstanceSummary.
        :type module_name: str

        :param stream_name:
            The value to assign to the stream_name property of this ModuleStreamProfileOnManagedInstanceSummary.
        :type stream_name: str

        :param profile_name:
            The value to assign to the profile_name property of this ModuleStreamProfileOnManagedInstanceSummary.
        :type profile_name: str

        :param status:
            The value to assign to the status property of this ModuleStreamProfileOnManagedInstanceSummary.
            Allowed values for this property are: "INSTALLED", "AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_modified:
            The value to assign to the time_modified property of this ModuleStreamProfileOnManagedInstanceSummary.
        :type time_modified: datetime

        """
        self.swagger_types = {
            'module_name': 'str',
            'stream_name': 'str',
            'profile_name': 'str',
            'status': 'str',
            'time_modified': 'datetime'
        }

        self.attribute_map = {
            'module_name': 'moduleName',
            'stream_name': 'streamName',
            'profile_name': 'profileName',
            'status': 'status',
            'time_modified': 'timeModified'
        }

        self._module_name = None
        self._stream_name = None
        self._profile_name = None
        self._status = None
        self._time_modified = None

    @property
    def module_name(self):
        """
        **[Required]** Gets the module_name of this ModuleStreamProfileOnManagedInstanceSummary.
        The name of the module that contains the stream profile


        :return: The module_name of this ModuleStreamProfileOnManagedInstanceSummary.
        :rtype: str
        """
        return self._module_name

    @module_name.setter
    def module_name(self, module_name):
        """
        Sets the module_name of this ModuleStreamProfileOnManagedInstanceSummary.
        The name of the module that contains the stream profile


        :param module_name: The module_name of this ModuleStreamProfileOnManagedInstanceSummary.
        :type: str
        """
        self._module_name = module_name

    @property
    def stream_name(self):
        """
        **[Required]** Gets the stream_name of this ModuleStreamProfileOnManagedInstanceSummary.
        The name of the stream that contains the profile


        :return: The stream_name of this ModuleStreamProfileOnManagedInstanceSummary.
        :rtype: str
        """
        return self._stream_name

    @stream_name.setter
    def stream_name(self, stream_name):
        """
        Sets the stream_name of this ModuleStreamProfileOnManagedInstanceSummary.
        The name of the stream that contains the profile


        :param stream_name: The stream_name of this ModuleStreamProfileOnManagedInstanceSummary.
        :type: str
        """
        self._stream_name = stream_name

    @property
    def profile_name(self):
        """
        **[Required]** Gets the profile_name of this ModuleStreamProfileOnManagedInstanceSummary.
        The name of the profile


        :return: The profile_name of this ModuleStreamProfileOnManagedInstanceSummary.
        :rtype: str
        """
        return self._profile_name

    @profile_name.setter
    def profile_name(self, profile_name):
        """
        Sets the profile_name of this ModuleStreamProfileOnManagedInstanceSummary.
        The name of the profile


        :param profile_name: The profile_name of this ModuleStreamProfileOnManagedInstanceSummary.
        :type: str
        """
        self._profile_name = profile_name

    @property
    def status(self):
        """
        **[Required]** Gets the status of this ModuleStreamProfileOnManagedInstanceSummary.
        The status of the profile.

        A profile with the \"INSTALLED\" status indicates that the profile has been
        installed.

        A profile with the \"AVAILABLE\" status indicates that the profile is
        not installed, but can be.

        Allowed values for this property are: "INSTALLED", "AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ModuleStreamProfileOnManagedInstanceSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ModuleStreamProfileOnManagedInstanceSummary.
        The status of the profile.

        A profile with the \"INSTALLED\" status indicates that the profile has been
        installed.

        A profile with the \"AVAILABLE\" status indicates that the profile is
        not installed, but can be.


        :param status: The status of this ModuleStreamProfileOnManagedInstanceSummary.
        :type: str
        """
        allowed_values = ["INSTALLED", "AVAILABLE"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def time_modified(self):
        """
        Gets the time_modified of this ModuleStreamProfileOnManagedInstanceSummary.
        The date and time of the last status change for this profile, as
        described in `RFC 3339`__,
        section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_modified of this ModuleStreamProfileOnManagedInstanceSummary.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this ModuleStreamProfileOnManagedInstanceSummary.
        The date and time of the last status change for this profile, as
        described in `RFC 3339`__,
        section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_modified: The time_modified of this ModuleStreamProfileOnManagedInstanceSummary.
        :type: datetime
        """
        self._time_modified = time_modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuditPolicyDimensions(object):
    """
    Details of aggregation dimensions used for summarizing audit policies.
    """

    #: A constant which can be used with the audit_policy_category property of a AuditPolicyDimensions.
    #: This constant has a value of "BASIC_ACTIVITY"
    AUDIT_POLICY_CATEGORY_BASIC_ACTIVITY = "BASIC_ACTIVITY"

    #: A constant which can be used with the audit_policy_category property of a AuditPolicyDimensions.
    #: This constant has a value of "ADMIN_USER_ACTIVITY"
    AUDIT_POLICY_CATEGORY_ADMIN_USER_ACTIVITY = "ADMIN_USER_ACTIVITY"

    #: A constant which can be used with the audit_policy_category property of a AuditPolicyDimensions.
    #: This constant has a value of "USER_ACTIVITY"
    AUDIT_POLICY_CATEGORY_USER_ACTIVITY = "USER_ACTIVITY"

    #: A constant which can be used with the audit_policy_category property of a AuditPolicyDimensions.
    #: This constant has a value of "ORACLE_PREDEFINED"
    AUDIT_POLICY_CATEGORY_ORACLE_PREDEFINED = "ORACLE_PREDEFINED"

    #: A constant which can be used with the audit_policy_category property of a AuditPolicyDimensions.
    #: This constant has a value of "COMPLIANCE_STANDARD"
    AUDIT_POLICY_CATEGORY_COMPLIANCE_STANDARD = "COMPLIANCE_STANDARD"

    #: A constant which can be used with the audit_policy_category property of a AuditPolicyDimensions.
    #: This constant has a value of "CUSTOM"
    AUDIT_POLICY_CATEGORY_CUSTOM = "CUSTOM"

    def __init__(self, **kwargs):
        """
        Initializes a new AuditPolicyDimensions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param audit_policy_category:
            The value to assign to the audit_policy_category property of this AuditPolicyDimensions.
            Allowed values for this property are: "BASIC_ACTIVITY", "ADMIN_USER_ACTIVITY", "USER_ACTIVITY", "ORACLE_PREDEFINED", "COMPLIANCE_STANDARD", "CUSTOM"
        :type audit_policy_category: str

        :param audit_policy_name:
            The value to assign to the audit_policy_name property of this AuditPolicyDimensions.
        :type audit_policy_name: str

        """
        self.swagger_types = {
            'audit_policy_category': 'str',
            'audit_policy_name': 'str'
        }

        self.attribute_map = {
            'audit_policy_category': 'auditPolicyCategory',
            'audit_policy_name': 'auditPolicyName'
        }

        self._audit_policy_category = None
        self._audit_policy_name = None

    @property
    def audit_policy_category(self):
        """
        Gets the audit_policy_category of this AuditPolicyDimensions.
        The category to which the audit policy belongs.

        Allowed values for this property are: "BASIC_ACTIVITY", "ADMIN_USER_ACTIVITY", "USER_ACTIVITY", "ORACLE_PREDEFINED", "COMPLIANCE_STANDARD", "CUSTOM"


        :return: The audit_policy_category of this AuditPolicyDimensions.
        :rtype: str
        """
        return self._audit_policy_category

    @audit_policy_category.setter
    def audit_policy_category(self, audit_policy_category):
        """
        Sets the audit_policy_category of this AuditPolicyDimensions.
        The category to which the audit policy belongs.


        :param audit_policy_category: The audit_policy_category of this AuditPolicyDimensions.
        :type: str
        """
        allowed_values = ["BASIC_ACTIVITY", "ADMIN_USER_ACTIVITY", "USER_ACTIVITY", "ORACLE_PREDEFINED", "COMPLIANCE_STANDARD", "CUSTOM"]
        if not value_allowed_none_or_none_sentinel(audit_policy_category, allowed_values):
            raise ValueError(
                "Invalid value for `audit_policy_category`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._audit_policy_category = audit_policy_category

    @property
    def audit_policy_name(self):
        """
        Gets the audit_policy_name of this AuditPolicyDimensions.
        Indicates the audit policy name. Refer to the `documentation`__ for seeded audit policy names. For custom policies, refer to the user-defined policy name created in the target database.

        __ https://docs.oracle.com/en/cloud/paas/data-safe/udscs/audit-policies.html#GUID-361A9A9A-7C21-4F5A-8945-9B3A0C472827


        :return: The audit_policy_name of this AuditPolicyDimensions.
        :rtype: str
        """
        return self._audit_policy_name

    @audit_policy_name.setter
    def audit_policy_name(self, audit_policy_name):
        """
        Sets the audit_policy_name of this AuditPolicyDimensions.
        Indicates the audit policy name. Refer to the `documentation`__ for seeded audit policy names. For custom policies, refer to the user-defined policy name created in the target database.

        __ https://docs.oracle.com/en/cloud/paas/data-safe/udscs/audit-policies.html#GUID-361A9A9A-7C21-4F5A-8945-9B3A0C472827


        :param audit_policy_name: The audit_policy_name of this AuditPolicyDimensions.
        :type: str
        """
        self._audit_policy_name = audit_policy_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryResultMetadataSummary(object):
    """
    Summary containing the metadata about the query result set.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryResultMetadataSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param query_result_row_type_summaries:
            The value to assign to the query_result_row_type_summaries property of this QueryResultMetadataSummary.
        :type query_result_row_type_summaries: list[oci.apm_traces.models.QueryResultRowTypeSummary]

        :param source_name:
            The value to assign to the source_name property of this QueryResultMetadataSummary.
        :type source_name: str

        :param query_results_grouped_by:
            The value to assign to the query_results_grouped_by property of this QueryResultMetadataSummary.
        :type query_results_grouped_by: list[oci.apm_traces.models.QueryResultsGroupedBySummary]

        :param query_results_ordered_by:
            The value to assign to the query_results_ordered_by property of this QueryResultMetadataSummary.
        :type query_results_ordered_by: list[oci.apm_traces.models.QueryResultsOrderedBySummary]

        :param time_series_interval_in_mins:
            The value to assign to the time_series_interval_in_mins property of this QueryResultMetadataSummary.
        :type time_series_interval_in_mins: int

        """
        self.swagger_types = {
            'query_result_row_type_summaries': 'list[QueryResultRowTypeSummary]',
            'source_name': 'str',
            'query_results_grouped_by': 'list[QueryResultsGroupedBySummary]',
            'query_results_ordered_by': 'list[QueryResultsOrderedBySummary]',
            'time_series_interval_in_mins': 'int'
        }

        self.attribute_map = {
            'query_result_row_type_summaries': 'queryResultRowTypeSummaries',
            'source_name': 'sourceName',
            'query_results_grouped_by': 'queryResultsGroupedBy',
            'query_results_ordered_by': 'queryResultsOrderedBy',
            'time_series_interval_in_mins': 'timeSeriesIntervalInMins'
        }

        self._query_result_row_type_summaries = None
        self._source_name = None
        self._query_results_grouped_by = None
        self._query_results_ordered_by = None
        self._time_series_interval_in_mins = None

    @property
    def query_result_row_type_summaries(self):
        """
        Gets the query_result_row_type_summaries of this QueryResultMetadataSummary.
        A collection of QueryResultRowTypeSummary objects that describe the type and properties of the individual row elements of the query rows
        being returned.  The i-th element in this list contains the QueryResultRowTypeSummary of the i-th key-value pair in the QueryResultRowData map.


        :return: The query_result_row_type_summaries of this QueryResultMetadataSummary.
        :rtype: list[oci.apm_traces.models.QueryResultRowTypeSummary]
        """
        return self._query_result_row_type_summaries

    @query_result_row_type_summaries.setter
    def query_result_row_type_summaries(self, query_result_row_type_summaries):
        """
        Sets the query_result_row_type_summaries of this QueryResultMetadataSummary.
        A collection of QueryResultRowTypeSummary objects that describe the type and properties of the individual row elements of the query rows
        being returned.  The i-th element in this list contains the QueryResultRowTypeSummary of the i-th key-value pair in the QueryResultRowData map.


        :param query_result_row_type_summaries: The query_result_row_type_summaries of this QueryResultMetadataSummary.
        :type: list[oci.apm_traces.models.QueryResultRowTypeSummary]
        """
        self._query_result_row_type_summaries = query_result_row_type_summaries

    @property
    def source_name(self):
        """
        Gets the source_name of this QueryResultMetadataSummary.
        Source of the query result set (traces, spans, and so on).


        :return: The source_name of this QueryResultMetadataSummary.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this QueryResultMetadataSummary.
        Source of the query result set (traces, spans, and so on).


        :param source_name: The source_name of this QueryResultMetadataSummary.
        :type: str
        """
        self._source_name = source_name

    @property
    def query_results_grouped_by(self):
        """
        Gets the query_results_grouped_by of this QueryResultMetadataSummary.
        Columns or attributes of the query rows  which are group by values.  This is a list of ResultsGroupedBy summary objects,
        and the list will contain as many elements as the attributes and aggregate functions in the group by clause in the select query.


        :return: The query_results_grouped_by of this QueryResultMetadataSummary.
        :rtype: list[oci.apm_traces.models.QueryResultsGroupedBySummary]
        """
        return self._query_results_grouped_by

    @query_results_grouped_by.setter
    def query_results_grouped_by(self, query_results_grouped_by):
        """
        Sets the query_results_grouped_by of this QueryResultMetadataSummary.
        Columns or attributes of the query rows  which are group by values.  This is a list of ResultsGroupedBy summary objects,
        and the list will contain as many elements as the attributes and aggregate functions in the group by clause in the select query.


        :param query_results_grouped_by: The query_results_grouped_by of this QueryResultMetadataSummary.
        :type: list[oci.apm_traces.models.QueryResultsGroupedBySummary]
        """
        self._query_results_grouped_by = query_results_grouped_by

    @property
    def query_results_ordered_by(self):
        """
        Gets the query_results_ordered_by of this QueryResultMetadataSummary.
        Order by which the query results are organized.  This is a list of queryResultsOrderedBy summary objects, and the list
        will contain more than one OrderedBy summary object, if the sort was multidimensional.


        :return: The query_results_ordered_by of this QueryResultMetadataSummary.
        :rtype: list[oci.apm_traces.models.QueryResultsOrderedBySummary]
        """
        return self._query_results_ordered_by

    @query_results_ordered_by.setter
    def query_results_ordered_by(self, query_results_ordered_by):
        """
        Sets the query_results_ordered_by of this QueryResultMetadataSummary.
        Order by which the query results are organized.  This is a list of queryResultsOrderedBy summary objects, and the list
        will contain more than one OrderedBy summary object, if the sort was multidimensional.


        :param query_results_ordered_by: The query_results_ordered_by of this QueryResultMetadataSummary.
        :type: list[oci.apm_traces.models.QueryResultsOrderedBySummary]
        """
        self._query_results_ordered_by = query_results_ordered_by

    @property
    def time_series_interval_in_mins(self):
        """
        Gets the time_series_interval_in_mins of this QueryResultMetadataSummary.
        Interval for the time series function in minutes.


        :return: The time_series_interval_in_mins of this QueryResultMetadataSummary.
        :rtype: int
        """
        return self._time_series_interval_in_mins

    @time_series_interval_in_mins.setter
    def time_series_interval_in_mins(self, time_series_interval_in_mins):
        """
        Sets the time_series_interval_in_mins of this QueryResultMetadataSummary.
        Interval for the time series function in minutes.


        :param time_series_interval_in_mins: The time_series_interval_in_mins of this QueryResultMetadataSummary.
        :type: int
        """
        self._time_series_interval_in_mins = time_series_interval_in_mins

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RateCardSummary(object):
    """
    Rate Card Summary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RateCardSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param product:
            The value to assign to the product property of this RateCardSummary.
        :type product: oci.osub_subscription.models.Product

        :param time_start:
            The value to assign to the time_start property of this RateCardSummary.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this RateCardSummary.
        :type time_end: datetime

        :param net_unit_price:
            The value to assign to the net_unit_price property of this RateCardSummary.
        :type net_unit_price: str

        :param discretionary_discount_percentage:
            The value to assign to the discretionary_discount_percentage property of this RateCardSummary.
        :type discretionary_discount_percentage: str

        :param overage_price:
            The value to assign to the overage_price property of this RateCardSummary.
        :type overage_price: str

        :param is_tier:
            The value to assign to the is_tier property of this RateCardSummary.
        :type is_tier: bool

        :param currency:
            The value to assign to the currency property of this RateCardSummary.
        :type currency: oci.osub_subscription.models.Currency

        :param rate_card_tiers:
            The value to assign to the rate_card_tiers property of this RateCardSummary.
        :type rate_card_tiers: list[oci.osub_subscription.models.RateCardTier]

        """
        self.swagger_types = {
            'product': 'Product',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'net_unit_price': 'str',
            'discretionary_discount_percentage': 'str',
            'overage_price': 'str',
            'is_tier': 'bool',
            'currency': 'Currency',
            'rate_card_tiers': 'list[RateCardTier]'
        }

        self.attribute_map = {
            'product': 'product',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'net_unit_price': 'netUnitPrice',
            'discretionary_discount_percentage': 'discretionaryDiscountPercentage',
            'overage_price': 'overagePrice',
            'is_tier': 'isTier',
            'currency': 'currency',
            'rate_card_tiers': 'rateCardTiers'
        }

        self._product = None
        self._time_start = None
        self._time_end = None
        self._net_unit_price = None
        self._discretionary_discount_percentage = None
        self._overage_price = None
        self._is_tier = None
        self._currency = None
        self._rate_card_tiers = None

    @property
    def product(self):
        """
        **[Required]** Gets the product of this RateCardSummary.

        :return: The product of this RateCardSummary.
        :rtype: oci.osub_subscription.models.Product
        """
        return self._product

    @product.setter
    def product(self, product):
        """
        Sets the product of this RateCardSummary.

        :param product: The product of this RateCardSummary.
        :type: oci.osub_subscription.models.Product
        """
        self._product = product

    @property
    def time_start(self):
        """
        Gets the time_start of this RateCardSummary.
        Rate card start date


        :return: The time_start of this RateCardSummary.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this RateCardSummary.
        Rate card start date


        :param time_start: The time_start of this RateCardSummary.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this RateCardSummary.
        Rate card end date


        :return: The time_end of this RateCardSummary.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this RateCardSummary.
        Rate card end date


        :param time_end: The time_end of this RateCardSummary.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def net_unit_price(self):
        """
        **[Required]** Gets the net_unit_price of this RateCardSummary.
        Rate card net unit price


        :return: The net_unit_price of this RateCardSummary.
        :rtype: str
        """
        return self._net_unit_price

    @net_unit_price.setter
    def net_unit_price(self, net_unit_price):
        """
        Sets the net_unit_price of this RateCardSummary.
        Rate card net unit price


        :param net_unit_price: The net_unit_price of this RateCardSummary.
        :type: str
        """
        self._net_unit_price = net_unit_price

    @property
    def discretionary_discount_percentage(self):
        """
        Gets the discretionary_discount_percentage of this RateCardSummary.
        Rate card discretionary discount percentage


        :return: The discretionary_discount_percentage of this RateCardSummary.
        :rtype: str
        """
        return self._discretionary_discount_percentage

    @discretionary_discount_percentage.setter
    def discretionary_discount_percentage(self, discretionary_discount_percentage):
        """
        Sets the discretionary_discount_percentage of this RateCardSummary.
        Rate card discretionary discount percentage


        :param discretionary_discount_percentage: The discretionary_discount_percentage of this RateCardSummary.
        :type: str
        """
        self._discretionary_discount_percentage = discretionary_discount_percentage

    @property
    def overage_price(self):
        """
        **[Required]** Gets the overage_price of this RateCardSummary.
        Rate card overage price


        :return: The overage_price of this RateCardSummary.
        :rtype: str
        """
        return self._overage_price

    @overage_price.setter
    def overage_price(self, overage_price):
        """
        Sets the overage_price of this RateCardSummary.
        Rate card overage price


        :param overage_price: The overage_price of this RateCardSummary.
        :type: str
        """
        self._overage_price = overage_price

    @property
    def is_tier(self):
        """
        Gets the is_tier of this RateCardSummary.
        Rate card price tier flag


        :return: The is_tier of this RateCardSummary.
        :rtype: bool
        """
        return self._is_tier

    @is_tier.setter
    def is_tier(self, is_tier):
        """
        Sets the is_tier of this RateCardSummary.
        Rate card price tier flag


        :param is_tier: The is_tier of this RateCardSummary.
        :type: bool
        """
        self._is_tier = is_tier

    @property
    def currency(self):
        """
        Gets the currency of this RateCardSummary.

        :return: The currency of this RateCardSummary.
        :rtype: oci.osub_subscription.models.Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this RateCardSummary.

        :param currency: The currency of this RateCardSummary.
        :type: oci.osub_subscription.models.Currency
        """
        self._currency = currency

    @property
    def rate_card_tiers(self):
        """
        Gets the rate_card_tiers of this RateCardSummary.
        List of tiered rate card prices


        :return: The rate_card_tiers of this RateCardSummary.
        :rtype: list[oci.osub_subscription.models.RateCardTier]
        """
        return self._rate_card_tiers

    @rate_card_tiers.setter
    def rate_card_tiers(self, rate_card_tiers):
        """
        Sets the rate_card_tiers of this RateCardSummary.
        List of tiered rate card prices


        :param rate_card_tiers: The rate_card_tiers of this RateCardSummary.
        :type: list[oci.osub_subscription.models.RateCardTier]
        """
        self._rate_card_tiers = rate_card_tiers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry, circuit_breaker  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import ocvp_type_mapping
missing = Sentinel("Missing")


class EsxiHostClient(object):
    """
    Use the Oracle Cloud VMware API to create SDDCs and manage ESXi hosts and software.
    For more information, see [Oracle Cloud VMware Solution](/iaas/Content/VMware/Concepts/ocvsoverview.htm).
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

        :param obj circuit_breaker_strategy: (optional)
            A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
            The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.

        :param function circuit_breaker_callback: (optional)
            Callback function to receive any exceptions triggerred by the circuit breaker.

        :param allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
            allow control characters to be in the response object.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20200501',
            'service_endpoint_template': 'https://ocvps.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False),
            'circuit_breaker_strategy': kwargs.get('circuit_breaker_strategy', circuit_breaker.GLOBAL_CIRCUIT_BREAKER_STRATEGY)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
        if 'allow_control_chars' in kwargs:
            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
        self.base_client = BaseClient("esxi_host", config, signer, ocvp_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')
        self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')

    def create_esxi_host(self, create_esxi_host_details, **kwargs):
        """
        Adds another ESXi host to an existing SDDC. The attributes of the specified
        `Sddc` determine the VMware software and other configuration settings used
        by the ESXi host.

        Use the :class:`WorkRequest` operations to track the
        creation of the ESXi host.


        :param oci.ocvp.models.CreateEsxiHostDetails create_esxi_host_details: (required)
            Details for the ESXi host.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations (for example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            may be rejected).

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation uses :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` as default if no retry strategy is provided.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/ocvp/create_esxi_host.py.html>`__ to see an example of how to use create_esxi_host API.
        """
        resource_path = "/esxiHosts"
        method = "POST"
        operation_name = "create_esxi_host"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/vmware/20200501/EsxiHost/CreateEsxiHost"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_esxi_host got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )
        if retry_strategy is None:
            retry_strategy = retry.DEFAULT_RETRY_STRATEGY

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_esxi_host_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_esxi_host_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def delete_esxi_host(self, esxi_host_id, **kwargs):
        """
        Deletes the specified ESXi host. Before deleting the host, back up or
        migrate any VMware workloads running on it.

        When you delete an ESXi host, Oracle does not remove the node
        configuration within the VMware environment itself. That is
        your responsibility.

        **Note:** If you delete EXSi hosts from the SDDC to total less than 3,
        you are still billed for the 3 minimum recommended EXSi hosts. Also,
        you cannot add more VMware workloads to the SDDC until it again has at
        least 3 ESXi hosts.

        Use the :class:`WorkRequest` operations to track the
        deletion of the ESXi host.


        :param str esxi_host_id: (required)
            The `OCID`__ of the ESXi host.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation uses :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` as default if no retry strategy is provided.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/ocvp/delete_esxi_host.py.html>`__ to see an example of how to use delete_esxi_host API.
        """
        resource_path = "/esxiHosts/{esxiHostId}"
        method = "DELETE"
        operation_name = "delete_esxi_host"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/vmware/20200501/EsxiHost/DeleteEsxiHost"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_esxi_host got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "esxiHostId": esxi_host_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )
        if retry_strategy is None:
            retry_strategy = retry.DEFAULT_RETRY_STRATEGY

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def get_esxi_host(self, esxi_host_id, **kwargs):
        """
        Gets the specified ESXi host's information.


        :param str esxi_host_id: (required)
            The `OCID`__ of the ESXi host.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation uses :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` as default if no retry strategy is provided.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.EsxiHost`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/ocvp/get_esxi_host.py.html>`__ to see an example of how to use get_esxi_host API.
        """
        resource_path = "/esxiHosts/{esxiHostId}"
        method = "GET"
        operation_name = "get_esxi_host"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/vmware/20200501/EsxiHost/GetEsxiHost"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_esxi_host got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "esxiHostId": esxi_host_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )
        if retry_strategy is None:
            retry_strategy = retry.DEFAULT_RETRY_STRATEGY

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="EsxiHost",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="EsxiHost",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def list_esxi_hosts(self, **kwargs):
        """
        Lists the ESXi hosts in the specified SDDC. The list can be filtered
        by Compute instance OCID or ESXi display name.

        Remember that in terms of implementation, an ESXi host is a Compute instance that
        is configured with the chosen bundle of VMware software. Each `EsxiHost`
        object has its own OCID (`id`), and a separate attribute for the OCID of
        the Compute instance (`computeInstanceId`). When filtering the list of
        ESXi hosts, you can specify the OCID of the Compute instance, not the
        ESXi host OCID.


        :param str sddc_id: (optional)
            The `OCID`__ of the SDDC.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str compute_instance_id: (optional)
            The `OCID`__ of the Compute instance.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str display_name: (optional)
            A filter to return only resources that match the given display name exactly.

        :param int limit: (optional)
            For list pagination. The maximum number of results per page, or items to return in a paginated
            \"List\" call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str page: (optional)
            For list pagination. The value of the `opc-next-page` response header from the previous \"List\"
            call. For important details about how pagination works, see
            `List Pagination`__.

            __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine

        :param str sort_order: (optional)
            The sort order to use, either ascending (`ASC`) or descending (`DESC`). The DISPLAYNAME sort order
            is case sensitive.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The field to sort by. You can provide one sort order (`sortOrder`). Default order for
            TIMECREATED is descending. Default order for DISPLAYNAME is ascending. The DISPLAYNAME
            sort order is case sensitive.

            **Note:** In general, some \"List\" operations (for example, `ListInstances`) let you
            optionally filter by availability domain if the scope of the resource type is within a
            single availability domain. If you call one of these \"List\" operations without specifying
            an availability domain, the resources are grouped by availability domain, then sorted.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param str lifecycle_state: (optional)
            The lifecycle state of the resource.

            Allowed values are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation uses :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` as default if no retry strategy is provided.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.EsxiHostCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/ocvp/list_esxi_hosts.py.html>`__ to see an example of how to use list_esxi_hosts API.
        """
        resource_path = "/esxiHosts"
        method = "GET"
        operation_name = "list_esxi_hosts"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/vmware/20200501/EsxiHostSummary/ListEsxiHosts"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "sddc_id",
            "compute_instance_id",
            "display_name",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id",
            "lifecycle_state"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_esxi_hosts got unknown kwargs: {!r}".format(extra_kwargs))

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        query_params = {
            "sddcId": kwargs.get("sddc_id", missing),
            "computeInstanceId": kwargs.get("compute_instance_id", missing),
            "displayName": kwargs.get("display_name", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing),
            "lifecycleState": kwargs.get("lifecycle_state", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )
        if retry_strategy is None:
            retry_strategy = retry.DEFAULT_RETRY_STRATEGY

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="EsxiHostCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="EsxiHostCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def update_esxi_host(self, esxi_host_id, update_esxi_host_details, **kwargs):
        """
        Updates the specified ESXi host.


        :param str esxi_host_id: (required)
            The `OCID`__ of the ESXi host.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.ocvp.models.UpdateEsxiHostDetails update_esxi_host_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call
            for a resource, set the `if-match` parameter to the value of the
            etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you
            provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            Unique identifier for the request. If you need to contact Oracle about a particular
            request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation uses :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` as default if no retry strategy is provided.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ocvp.models.EsxiHost`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/ocvp/update_esxi_host.py.html>`__ to see an example of how to use update_esxi_host API.
        """
        resource_path = "/esxiHosts/{esxiHostId}"
        method = "PUT"
        operation_name = "update_esxi_host"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/vmware/20200501/EsxiHost/UpdateEsxiHost"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_esxi_host got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "esxiHostId": esxi_host_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )
        if retry_strategy is None:
            retry_strategy = retry.DEFAULT_RETRY_STRATEGY

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_esxi_host_details,
                response_type="EsxiHost",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_esxi_host_details,
                response_type="EsxiHost",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AlertLogCountSummary(object):
    """
    The details for one alert log count entry.
    """

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "UNKNOWN"
    CATEGORY_UNKNOWN = "UNKNOWN"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "INCIDENT_ERROR"
    CATEGORY_INCIDENT_ERROR = "INCIDENT_ERROR"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "ERROR"
    CATEGORY_ERROR = "ERROR"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "WARNING"
    CATEGORY_WARNING = "WARNING"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "NOTIFICATION"
    CATEGORY_NOTIFICATION = "NOTIFICATION"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "TRACE"
    CATEGORY_TRACE = "TRACE"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "CRITICAL"
    CATEGORY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "SEVERE"
    CATEGORY_SEVERE = "SEVERE"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "IMPORTANT"
    CATEGORY_IMPORTANT = "IMPORTANT"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "NORMAL"
    CATEGORY_NORMAL = "NORMAL"

    #: A constant which can be used with the category property of a AlertLogCountSummary.
    #: This constant has a value of "OTHER"
    CATEGORY_OTHER = "OTHER"

    def __init__(self, **kwargs):
        """
        Initializes a new AlertLogCountSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param category:
            The value to assign to the category property of this AlertLogCountSummary.
            Allowed values for this property are: "UNKNOWN", "INCIDENT_ERROR", "ERROR", "WARNING", "NOTIFICATION", "TRACE", "CRITICAL", "SEVERE", "IMPORTANT", "NORMAL", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param count:
            The value to assign to the count property of this AlertLogCountSummary.
        :type count: int

        """
        self.swagger_types = {
            'category': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'category': 'category',
            'count': 'count'
        }

        self._category = None
        self._count = None

    @property
    def category(self):
        """
        **[Required]** Gets the category of this AlertLogCountSummary.
        The category of different alert logs.

        Allowed values for this property are: "UNKNOWN", "INCIDENT_ERROR", "ERROR", "WARNING", "NOTIFICATION", "TRACE", "CRITICAL", "SEVERE", "IMPORTANT", "NORMAL", "OTHER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The category of this AlertLogCountSummary.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this AlertLogCountSummary.
        The category of different alert logs.


        :param category: The category of this AlertLogCountSummary.
        :type: str
        """
        allowed_values = ["UNKNOWN", "INCIDENT_ERROR", "ERROR", "WARNING", "NOTIFICATION", "TRACE", "CRITICAL", "SEVERE", "IMPORTANT", "NORMAL", "OTHER"]
        if not value_allowed_none_or_none_sentinel(category, allowed_values):
            category = 'UNKNOWN_ENUM_VALUE'
        self._category = category

    @property
    def count(self):
        """
        **[Required]** Gets the count of this AlertLogCountSummary.
        The count of alert logs with specific category.


        :return: The count of this AlertLogCountSummary.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this AlertLogCountSummary.
        The count of alert logs with specific category.


        :param count: The count of this AlertLogCountSummary.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBuildPipelineStageDetails(object):
    """
    The information about a new stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBuildPipelineStageDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.CreateDeliverArtifactStageDetails`
        * :class:`~oci.devops.models.CreateTriggerDeploymentStageDetails`
        * :class:`~oci.devops.models.CreateWaitStageDetails`
        * :class:`~oci.devops.models.CreateBuildStageDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateBuildPipelineStageDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateBuildPipelineStageDetails.
        :type description: str

        :param build_pipeline_stage_type:
            The value to assign to the build_pipeline_stage_type property of this CreateBuildPipelineStageDetails.
        :type build_pipeline_stage_type: str

        :param build_pipeline_id:
            The value to assign to the build_pipeline_id property of this CreateBuildPipelineStageDetails.
        :type build_pipeline_id: str

        :param build_pipeline_stage_predecessor_collection:
            The value to assign to the build_pipeline_stage_predecessor_collection property of this CreateBuildPipelineStageDetails.
        :type build_pipeline_stage_predecessor_collection: oci.devops.models.BuildPipelineStagePredecessorCollection

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateBuildPipelineStageDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateBuildPipelineStageDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'build_pipeline_stage_type': 'str',
            'build_pipeline_id': 'str',
            'build_pipeline_stage_predecessor_collection': 'BuildPipelineStagePredecessorCollection',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'build_pipeline_stage_type': 'buildPipelineStageType',
            'build_pipeline_id': 'buildPipelineId',
            'build_pipeline_stage_predecessor_collection': 'buildPipelineStagePredecessorCollection',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._build_pipeline_stage_type = None
        self._build_pipeline_id = None
        self._build_pipeline_stage_predecessor_collection = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['buildPipelineStageType']

        if type == 'DELIVER_ARTIFACT':
            return 'CreateDeliverArtifactStageDetails'

        if type == 'TRIGGER_DEPLOYMENT_PIPELINE':
            return 'CreateTriggerDeploymentStageDetails'

        if type == 'WAIT':
            return 'CreateWaitStageDetails'

        if type == 'BUILD':
            return 'CreateBuildStageDetails'
        else:
            return 'CreateBuildPipelineStageDetails'

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateBuildPipelineStageDetails.
        Stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.


        :return: The display_name of this CreateBuildPipelineStageDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateBuildPipelineStageDetails.
        Stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.


        :param display_name: The display_name of this CreateBuildPipelineStageDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateBuildPipelineStageDetails.
        Optional description about the stage.


        :return: The description of this CreateBuildPipelineStageDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateBuildPipelineStageDetails.
        Optional description about the stage.


        :param description: The description of this CreateBuildPipelineStageDetails.
        :type: str
        """
        self._description = description

    @property
    def build_pipeline_stage_type(self):
        """
        **[Required]** Gets the build_pipeline_stage_type of this CreateBuildPipelineStageDetails.
        Defines the stage type, which is one of the following: BUILD, DELIVER_ARTIFACT, WAIT, and TRIGGER_DEPLOYMENT_PIPELINE.


        :return: The build_pipeline_stage_type of this CreateBuildPipelineStageDetails.
        :rtype: str
        """
        return self._build_pipeline_stage_type

    @build_pipeline_stage_type.setter
    def build_pipeline_stage_type(self, build_pipeline_stage_type):
        """
        Sets the build_pipeline_stage_type of this CreateBuildPipelineStageDetails.
        Defines the stage type, which is one of the following: BUILD, DELIVER_ARTIFACT, WAIT, and TRIGGER_DEPLOYMENT_PIPELINE.


        :param build_pipeline_stage_type: The build_pipeline_stage_type of this CreateBuildPipelineStageDetails.
        :type: str
        """
        self._build_pipeline_stage_type = build_pipeline_stage_type

    @property
    def build_pipeline_id(self):
        """
        **[Required]** Gets the build_pipeline_id of this CreateBuildPipelineStageDetails.
        The OCID of the build pipeline.


        :return: The build_pipeline_id of this CreateBuildPipelineStageDetails.
        :rtype: str
        """
        return self._build_pipeline_id

    @build_pipeline_id.setter
    def build_pipeline_id(self, build_pipeline_id):
        """
        Sets the build_pipeline_id of this CreateBuildPipelineStageDetails.
        The OCID of the build pipeline.


        :param build_pipeline_id: The build_pipeline_id of this CreateBuildPipelineStageDetails.
        :type: str
        """
        self._build_pipeline_id = build_pipeline_id

    @property
    def build_pipeline_stage_predecessor_collection(self):
        """
        **[Required]** Gets the build_pipeline_stage_predecessor_collection of this CreateBuildPipelineStageDetails.

        :return: The build_pipeline_stage_predecessor_collection of this CreateBuildPipelineStageDetails.
        :rtype: oci.devops.models.BuildPipelineStagePredecessorCollection
        """
        return self._build_pipeline_stage_predecessor_collection

    @build_pipeline_stage_predecessor_collection.setter
    def build_pipeline_stage_predecessor_collection(self, build_pipeline_stage_predecessor_collection):
        """
        Sets the build_pipeline_stage_predecessor_collection of this CreateBuildPipelineStageDetails.

        :param build_pipeline_stage_predecessor_collection: The build_pipeline_stage_predecessor_collection of this CreateBuildPipelineStageDetails.
        :type: oci.devops.models.BuildPipelineStagePredecessorCollection
        """
        self._build_pipeline_stage_predecessor_collection = build_pipeline_stage_predecessor_collection

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateBuildPipelineStageDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateBuildPipelineStageDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateBuildPipelineStageDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateBuildPipelineStageDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateBuildPipelineStageDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateBuildPipelineStageDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateBuildPipelineStageDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateBuildPipelineStageDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DigitalAssistant(object):
    """
    Digital Assistant metadata.
    """

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistant.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_details property of a DigitalAssistant.
    #: This constant has a value of "PUBLISHED"
    LIFECYCLE_DETAILS_PUBLISHED = "PUBLISHED"

    #: A constant which can be used with the lifecycle_details property of a DigitalAssistant.
    #: This constant has a value of "DRAFT"
    LIFECYCLE_DETAILS_DRAFT = "DRAFT"

    #: A constant which can be used with the multilingual_mode property of a DigitalAssistant.
    #: This constant has a value of "NATIVE"
    MULTILINGUAL_MODE_NATIVE = "NATIVE"

    #: A constant which can be used with the multilingual_mode property of a DigitalAssistant.
    #: This constant has a value of "TRANSLATION"
    MULTILINGUAL_MODE_TRANSLATION = "TRANSLATION"

    def __init__(self, **kwargs):
        """
        Initializes a new DigitalAssistant object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DigitalAssistant.
        :type id: str

        :param name:
            The value to assign to the name property of this DigitalAssistant.
        :type name: str

        :param version:
            The value to assign to the version property of this DigitalAssistant.
        :type version: str

        :param display_name:
            The value to assign to the display_name property of this DigitalAssistant.
        :type display_name: str

        :param category:
            The value to assign to the category property of this DigitalAssistant.
        :type category: str

        :param description:
            The value to assign to the description property of this DigitalAssistant.
        :type description: str

        :param namespace:
            The value to assign to the namespace property of this DigitalAssistant.
        :type namespace: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DigitalAssistant.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DigitalAssistant.
            Allowed values for this property are: "PUBLISHED", "DRAFT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_details: str

        :param platform_version:
            The value to assign to the platform_version property of this DigitalAssistant.
        :type platform_version: str

        :param base_id:
            The value to assign to the base_id property of this DigitalAssistant.
        :type base_id: str

        :param multilingual_mode:
            The value to assign to the multilingual_mode property of this DigitalAssistant.
            Allowed values for this property are: "NATIVE", "TRANSLATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type multilingual_mode: str

        :param primary_language_tag:
            The value to assign to the primary_language_tag property of this DigitalAssistant.
        :type primary_language_tag: str

        :param native_language_tags:
            The value to assign to the native_language_tags property of this DigitalAssistant.
        :type native_language_tags: list[str]

        :param time_created:
            The value to assign to the time_created property of this DigitalAssistant.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DigitalAssistant.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DigitalAssistant.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DigitalAssistant.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'str',
            'display_name': 'str',
            'category': 'str',
            'description': 'str',
            'namespace': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'platform_version': 'str',
            'base_id': 'str',
            'multilingual_mode': 'str',
            'primary_language_tag': 'str',
            'native_language_tags': 'list[str]',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'display_name': 'displayName',
            'category': 'category',
            'description': 'description',
            'namespace': 'namespace',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'platform_version': 'platformVersion',
            'base_id': 'baseId',
            'multilingual_mode': 'multilingualMode',
            'primary_language_tag': 'primaryLanguageTag',
            'native_language_tags': 'nativeLanguageTags',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._name = None
        self._version = None
        self._display_name = None
        self._category = None
        self._description = None
        self._namespace = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._platform_version = None
        self._base_id = None
        self._multilingual_mode = None
        self._primary_language_tag = None
        self._native_language_tags = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DigitalAssistant.
        Unique immutable identifier that was assigned when the resource was created.


        :return: The id of this DigitalAssistant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DigitalAssistant.
        Unique immutable identifier that was assigned when the resource was created.


        :param id: The id of this DigitalAssistant.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this DigitalAssistant.
        The reource's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.


        :return: The name of this DigitalAssistant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DigitalAssistant.
        The reource's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.


        :param name: The name of this DigitalAssistant.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        **[Required]** Gets the version of this DigitalAssistant.
        The resource's version. The version can only contain numbers, letters, periods, underscores, dashes or spaces.  The version must begin with a letter or a number.


        :return: The version of this DigitalAssistant.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DigitalAssistant.
        The resource's version. The version can only contain numbers, letters, periods, underscores, dashes or spaces.  The version must begin with a letter or a number.


        :param version: The version of this DigitalAssistant.
        :type: str
        """
        self._version = version

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DigitalAssistant.
        The resource's display name.


        :return: The display_name of this DigitalAssistant.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DigitalAssistant.
        The resource's display name.


        :param display_name: The display_name of this DigitalAssistant.
        :type: str
        """
        self._display_name = display_name

    @property
    def category(self):
        """
        Gets the category of this DigitalAssistant.
        The resource's category.  This is used to group resource's together.


        :return: The category of this DigitalAssistant.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this DigitalAssistant.
        The resource's category.  This is used to group resource's together.


        :param category: The category of this DigitalAssistant.
        :type: str
        """
        self._category = category

    @property
    def description(self):
        """
        Gets the description of this DigitalAssistant.
        A short description of the resource.


        :return: The description of this DigitalAssistant.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DigitalAssistant.
        A short description of the resource.


        :param description: The description of this DigitalAssistant.
        :type: str
        """
        self._description = description

    @property
    def namespace(self):
        """
        Gets the namespace of this DigitalAssistant.
        The resource's namespace.


        :return: The namespace of this DigitalAssistant.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this DigitalAssistant.
        The resource's namespace.


        :param namespace: The namespace of this DigitalAssistant.
        :type: str
        """
        self._namespace = namespace

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DigitalAssistant.
        The resource's current state.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DigitalAssistant.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DigitalAssistant.
        The resource's current state.


        :param lifecycle_state: The lifecycle_state of this DigitalAssistant.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        **[Required]** Gets the lifecycle_details of this DigitalAssistant.
        The resource's publish state.

        Allowed values for this property are: "PUBLISHED", "DRAFT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_details of this DigitalAssistant.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DigitalAssistant.
        The resource's publish state.


        :param lifecycle_details: The lifecycle_details of this DigitalAssistant.
        :type: str
        """
        allowed_values = ["PUBLISHED", "DRAFT"]
        if not value_allowed_none_or_none_sentinel(lifecycle_details, allowed_values):
            lifecycle_details = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_details = lifecycle_details

    @property
    def platform_version(self):
        """
        **[Required]** Gets the platform_version of this DigitalAssistant.
        The ODA Platform Version for this resource.


        :return: The platform_version of this DigitalAssistant.
        :rtype: str
        """
        return self._platform_version

    @platform_version.setter
    def platform_version(self, platform_version):
        """
        Sets the platform_version of this DigitalAssistant.
        The ODA Platform Version for this resource.


        :param platform_version: The platform_version of this DigitalAssistant.
        :type: str
        """
        self._platform_version = platform_version

    @property
    def base_id(self):
        """
        Gets the base_id of this DigitalAssistant.
        The unique identifier for the base reource (when this resource extends another).


        :return: The base_id of this DigitalAssistant.
        :rtype: str
        """
        return self._base_id

    @base_id.setter
    def base_id(self, base_id):
        """
        Sets the base_id of this DigitalAssistant.
        The unique identifier for the base reource (when this resource extends another).


        :param base_id: The base_id of this DigitalAssistant.
        :type: str
        """
        self._base_id = base_id

    @property
    def multilingual_mode(self):
        """
        Gets the multilingual_mode of this DigitalAssistant.
        The multilingual mode for the resource.

        Allowed values for this property are: "NATIVE", "TRANSLATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The multilingual_mode of this DigitalAssistant.
        :rtype: str
        """
        return self._multilingual_mode

    @multilingual_mode.setter
    def multilingual_mode(self, multilingual_mode):
        """
        Sets the multilingual_mode of this DigitalAssistant.
        The multilingual mode for the resource.


        :param multilingual_mode: The multilingual_mode of this DigitalAssistant.
        :type: str
        """
        allowed_values = ["NATIVE", "TRANSLATION"]
        if not value_allowed_none_or_none_sentinel(multilingual_mode, allowed_values):
            multilingual_mode = 'UNKNOWN_ENUM_VALUE'
        self._multilingual_mode = multilingual_mode

    @property
    def primary_language_tag(self):
        """
        Gets the primary_language_tag of this DigitalAssistant.
        The primary language for the resource.


        :return: The primary_language_tag of this DigitalAssistant.
        :rtype: str
        """
        return self._primary_language_tag

    @primary_language_tag.setter
    def primary_language_tag(self, primary_language_tag):
        """
        Sets the primary_language_tag of this DigitalAssistant.
        The primary language for the resource.


        :param primary_language_tag: The primary_language_tag of this DigitalAssistant.
        :type: str
        """
        self._primary_language_tag = primary_language_tag

    @property
    def native_language_tags(self):
        """
        Gets the native_language_tags of this DigitalAssistant.
        A list of native languages supported by this resource.


        :return: The native_language_tags of this DigitalAssistant.
        :rtype: list[str]
        """
        return self._native_language_tags

    @native_language_tags.setter
    def native_language_tags(self, native_language_tags):
        """
        Sets the native_language_tags of this DigitalAssistant.
        A list of native languages supported by this resource.


        :param native_language_tags: The native_language_tags of this DigitalAssistant.
        :type: list[str]
        """
        self._native_language_tags = native_language_tags

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DigitalAssistant.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this DigitalAssistant.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DigitalAssistant.
        When the resource was created. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this DigitalAssistant.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this DigitalAssistant.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this DigitalAssistant.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DigitalAssistant.
        When the resource was last updated. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this DigitalAssistant.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DigitalAssistant.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DigitalAssistant.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DigitalAssistant.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DigitalAssistant.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DigitalAssistant.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DigitalAssistant.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DigitalAssistant.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DigitalAssistant.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DigitalAssistantParameterSummary(object):
    """
    Metadata for a Digital Assistant Parameter property.
    """

    #: A constant which can be used with the type property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "STRING"
    TYPE_STRING = "STRING"

    #: A constant which can be used with the type property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "INTEGER"
    TYPE_INTEGER = "INTEGER"

    #: A constant which can be used with the type property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "FLOAT"
    TYPE_FLOAT = "FLOAT"

    #: A constant which can be used with the type property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "BOOLEAN"
    TYPE_BOOLEAN = "BOOLEAN"

    #: A constant which can be used with the type property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "SECURE"
    TYPE_SECURE = "SECURE"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DigitalAssistantParameterSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DigitalAssistantParameterSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DigitalAssistantParameterSummary.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this DigitalAssistantParameterSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DigitalAssistantParameterSummary.
        :type description: str

        :param type:
            The value to assign to the type property of this DigitalAssistantParameterSummary.
            Allowed values for this property are: "STRING", "INTEGER", "FLOAT", "BOOLEAN", "SECURE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param value:
            The value to assign to the value property of this DigitalAssistantParameterSummary.
        :type value: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DigitalAssistantParameterSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'name': 'str',
            'display_name': 'str',
            'description': 'str',
            'type': 'str',
            'value': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'display_name': 'displayName',
            'description': 'description',
            'type': 'type',
            'value': 'value',
            'lifecycle_state': 'lifecycleState'
        }

        self._name = None
        self._display_name = None
        self._description = None
        self._type = None
        self._value = None
        self._lifecycle_state = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this DigitalAssistantParameterSummary.
        The Parameter name.  This must be unique within the parent resource.


        :return: The name of this DigitalAssistantParameterSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DigitalAssistantParameterSummary.
        The Parameter name.  This must be unique within the parent resource.


        :param name: The name of this DigitalAssistantParameterSummary.
        :type: str
        """
        self._name = name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DigitalAssistantParameterSummary.
        The display name for the Parameter.


        :return: The display_name of this DigitalAssistantParameterSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DigitalAssistantParameterSummary.
        The display name for the Parameter.


        :param display_name: The display_name of this DigitalAssistantParameterSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this DigitalAssistantParameterSummary.
        A description of the Parameter.


        :return: The description of this DigitalAssistantParameterSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DigitalAssistantParameterSummary.
        A description of the Parameter.


        :param description: The description of this DigitalAssistantParameterSummary.
        :type: str
        """
        self._description = description

    @property
    def type(self):
        """
        **[Required]** Gets the type of this DigitalAssistantParameterSummary.
        The value type.

        Allowed values for this property are: "STRING", "INTEGER", "FLOAT", "BOOLEAN", "SECURE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this DigitalAssistantParameterSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DigitalAssistantParameterSummary.
        The value type.


        :param type: The type of this DigitalAssistantParameterSummary.
        :type: str
        """
        allowed_values = ["STRING", "INTEGER", "FLOAT", "BOOLEAN", "SECURE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def value(self):
        """
        Gets the value of this DigitalAssistantParameterSummary.
        The current value.  The value will be interpreted based on the `type`.


        :return: The value of this DigitalAssistantParameterSummary.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this DigitalAssistantParameterSummary.
        The current value.  The value will be interpreted based on the `type`.


        :param value: The value of this DigitalAssistantParameterSummary.
        :type: str
        """
        self._value = value

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DigitalAssistantParameterSummary.
        The Parameter's current state.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DigitalAssistantParameterSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DigitalAssistantParameterSummary.
        The Parameter's current state.


        :param lifecycle_state: The lifecycle_state of this DigitalAssistantParameterSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# Contains classes for defining and building circuit breaker strategies.
import logging
from oci.exceptions import TransientServiceError

logger = logging.getLogger(__name__)

DEFAULT_CIRCUIT_BREAKER_FAILURE_STATUSES_AND_CODES = {
    409: ['IncorrectState'],
    429: [],
    500: [],
    502: [],
    503: [],
    504: []
}


class CircuitBreakerStrategy(object):
    """
        A class which can build a circuit breaker strategy based on provided criteria.

        This builder is intended as a convenience, but callers are also able to bypass this and construct
        circuit breaker strategies directly.

        :param int failure_threshold: (optional)
            The failure_threshold parameter specifies the number of subsequent failures that causes to circuit breaker
            to move from CLOSED to OPEN state. This parameter takes an integer value with 10 being the default value.

        :param int recovery_timeout: (optional)
            The recovery timeout is the time in seconds that the circuit breaker waits till it moves from an
            OPEN to HALF-OPEN state. This parameter takes in an integer with 30 seconds being the default value.

        :param dict failure_statuses_and_codes: (optional)
            This parameter takes in a dict object of type (int, list(str)) which consist of
            the status code and the list of error codes the circuit breaker takes in account for failure threshold.
            If the list of error code is an empty list the circuit breaker would mark all errors as failure which has
            that specific status code regardless of the error code.

            defaults to:
            {
                409: ['IncorrectState'],
                429: [],
                500: [],
                502: [],
                503: [],
                504: []
            }

        :param str name: (optional)
            The name of Circuit Breaker. Each circuit breaker instance is by internally made unique to a client. This
            makes sure that a circuit breaker of one client does not interfere with the operations of the other clients,
            even if they belong to the same service. In a rare case, when it is intended to share the same Circuit Breaker
            across multiple clients, a CircuitBreakerStrategy object can be made with the name value set as desired
            and passed to the clients meant to share the circuit breaker. In this scenario failures from any client
            add to the failure threshold of the circuit breaker shared by all clients.
    """

    def __init__(self, **kwargs):
        """
            Creates a new builder and initializes it based on any provided parameters.
        """
        self.failure_threshold = kwargs.get('failure_threshold', 10)
        self.recovery_timeout = kwargs.get('recovery_timeout', 30)
        self.expected_exception = TransientServiceError
        self.failure_statuses_and_codes = kwargs.get('failure_statuses_and_codes',
                                                     DEFAULT_CIRCUIT_BREAKER_FAILURE_STATUSES_AND_CODES)
        self.name = kwargs.get('name', None)

    def is_transient_error(self, status_code, service_code):
        logger.debug('Is transient error status code:{} error code:{}'.format(status_code, service_code))
        if status_code in self.failure_statuses_and_codes:
            error_code = self.failure_statuses_and_codes[status_code]
            if not error_code:
                return True
            return service_code in error_code
        logger.debug(
            'status code:{} not in failure_statuses_and_codes:{}'.format(status_code, self.failure_statuses_and_codes))
        return False


class NoCircuitBreakerStrategy(object):
    """
           A class which represents that no circuit breaker strategy is to be used for the Client.
    """

    def __init__(self):
        pass



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DocumentMetadata(object):
    """
    The document information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DocumentMetadata object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param page_count:
            The value to assign to the page_count property of this DocumentMetadata.
        :type page_count: int

        :param mime_type:
            The value to assign to the mime_type property of this DocumentMetadata.
        :type mime_type: str

        """
        self.swagger_types = {
            'page_count': 'int',
            'mime_type': 'str'
        }

        self.attribute_map = {
            'page_count': 'pageCount',
            'mime_type': 'mimeType'
        }

        self._page_count = None
        self._mime_type = None

    @property
    def page_count(self):
        """
        **[Required]** Gets the page_count of this DocumentMetadata.
        Teh number of pages in the document.


        :return: The page_count of this DocumentMetadata.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this DocumentMetadata.
        Teh number of pages in the document.


        :param page_count: The page_count of this DocumentMetadata.
        :type: int
        """
        self._page_count = page_count

    @property
    def mime_type(self):
        """
        **[Required]** Gets the mime_type of this DocumentMetadata.
        The result data format.


        :return: The mime_type of this DocumentMetadata.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """
        Sets the mime_type of this DocumentMetadata.
        The result data format.


        :param mime_type: The mime_type of this DocumentMetadata.
        :type: str
        """
        self._mime_type = mime_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MacsecKey(object):
    """
    An object defining the Secrets-in-Vault OCIDs representing the MACsec key.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MacsecKey object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param connectivity_association_name_secret_id:
            The value to assign to the connectivity_association_name_secret_id property of this MacsecKey.
        :type connectivity_association_name_secret_id: str

        :param connectivity_association_name_secret_version:
            The value to assign to the connectivity_association_name_secret_version property of this MacsecKey.
        :type connectivity_association_name_secret_version: int

        :param connectivity_association_key_secret_id:
            The value to assign to the connectivity_association_key_secret_id property of this MacsecKey.
        :type connectivity_association_key_secret_id: str

        :param connectivity_association_key_secret_version:
            The value to assign to the connectivity_association_key_secret_version property of this MacsecKey.
        :type connectivity_association_key_secret_version: int

        """
        self.swagger_types = {
            'connectivity_association_name_secret_id': 'str',
            'connectivity_association_name_secret_version': 'int',
            'connectivity_association_key_secret_id': 'str',
            'connectivity_association_key_secret_version': 'int'
        }

        self.attribute_map = {
            'connectivity_association_name_secret_id': 'connectivityAssociationNameSecretId',
            'connectivity_association_name_secret_version': 'connectivityAssociationNameSecretVersion',
            'connectivity_association_key_secret_id': 'connectivityAssociationKeySecretId',
            'connectivity_association_key_secret_version': 'connectivityAssociationKeySecretVersion'
        }

        self._connectivity_association_name_secret_id = None
        self._connectivity_association_name_secret_version = None
        self._connectivity_association_key_secret_id = None
        self._connectivity_association_key_secret_version = None

    @property
    def connectivity_association_name_secret_id(self):
        """
        **[Required]** Gets the connectivity_association_name_secret_id of this MacsecKey.
        Secret `OCID`__ containing the Connectivity association Key Name (CKN) of this MACsec key.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The connectivity_association_name_secret_id of this MacsecKey.
        :rtype: str
        """
        return self._connectivity_association_name_secret_id

    @connectivity_association_name_secret_id.setter
    def connectivity_association_name_secret_id(self, connectivity_association_name_secret_id):
        """
        Sets the connectivity_association_name_secret_id of this MacsecKey.
        Secret `OCID`__ containing the Connectivity association Key Name (CKN) of this MACsec key.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param connectivity_association_name_secret_id: The connectivity_association_name_secret_id of this MacsecKey.
        :type: str
        """
        self._connectivity_association_name_secret_id = connectivity_association_name_secret_id

    @property
    def connectivity_association_name_secret_version(self):
        """
        Gets the connectivity_association_name_secret_version of this MacsecKey.
        The secret version of the connectivity association name secret in Vault.


        :return: The connectivity_association_name_secret_version of this MacsecKey.
        :rtype: int
        """
        return self._connectivity_association_name_secret_version

    @connectivity_association_name_secret_version.setter
    def connectivity_association_name_secret_version(self, connectivity_association_name_secret_version):
        """
        Sets the connectivity_association_name_secret_version of this MacsecKey.
        The secret version of the connectivity association name secret in Vault.


        :param connectivity_association_name_secret_version: The connectivity_association_name_secret_version of this MacsecKey.
        :type: int
        """
        self._connectivity_association_name_secret_version = connectivity_association_name_secret_version

    @property
    def connectivity_association_key_secret_id(self):
        """
        **[Required]** Gets the connectivity_association_key_secret_id of this MacsecKey.
        Secret `OCID`__ containing the Connectivity Association Key (CAK) of this MACsec key.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The connectivity_association_key_secret_id of this MacsecKey.
        :rtype: str
        """
        return self._connectivity_association_key_secret_id

    @connectivity_association_key_secret_id.setter
    def connectivity_association_key_secret_id(self, connectivity_association_key_secret_id):
        """
        Sets the connectivity_association_key_secret_id of this MacsecKey.
        Secret `OCID`__ containing the Connectivity Association Key (CAK) of this MACsec key.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param connectivity_association_key_secret_id: The connectivity_association_key_secret_id of this MacsecKey.
        :type: str
        """
        self._connectivity_association_key_secret_id = connectivity_association_key_secret_id

    @property
    def connectivity_association_key_secret_version(self):
        """
        Gets the connectivity_association_key_secret_version of this MacsecKey.
        The secret version of the `connectivityAssociationKey` secret in Vault.


        :return: The connectivity_association_key_secret_version of this MacsecKey.
        :rtype: int
        """
        return self._connectivity_association_key_secret_version

    @connectivity_association_key_secret_version.setter
    def connectivity_association_key_secret_version(self, connectivity_association_key_secret_version):
        """
        Sets the connectivity_association_key_secret_version of this MacsecKey.
        The secret version of the `connectivityAssociationKey` secret in Vault.


        :param connectivity_association_key_secret_version: The connectivity_association_key_secret_version of this MacsecKey.
        :type: int
        """
        self._connectivity_association_key_secret_version = connectivity_association_key_secret_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_target_type_tablespace_details import CreateTargetTypeTablespaceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateADBDedicatedRemapTargetTablespaceDetails(CreateTargetTypeTablespaceDetails):
    """
    Migration tablespace settings valid for ADB-D target type using remap feature.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateADBDedicatedRemapTargetTablespaceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database_migration.models.CreateADBDedicatedRemapTargetTablespaceDetails.target_type` attribute
        of this class is ``ADB_D_REMAP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target_type:
            The value to assign to the target_type property of this CreateADBDedicatedRemapTargetTablespaceDetails.
            Allowed values for this property are: "ADB_S_REMAP", "ADB_D_REMAP", "ADB_D_AUTOCREATE", "NON_ADB_REMAP", "NON_ADB_AUTOCREATE"
        :type target_type: str

        :param remap_target:
            The value to assign to the remap_target property of this CreateADBDedicatedRemapTargetTablespaceDetails.
        :type remap_target: str

        """
        self.swagger_types = {
            'target_type': 'str',
            'remap_target': 'str'
        }

        self.attribute_map = {
            'target_type': 'targetType',
            'remap_target': 'remapTarget'
        }

        self._target_type = None
        self._remap_target = None
        self._target_type = 'ADB_D_REMAP'

    @property
    def remap_target(self):
        """
        Gets the remap_target of this CreateADBDedicatedRemapTargetTablespaceDetails.
        Name of tablespace at target to which the source database tablespace need to be remapped.


        :return: The remap_target of this CreateADBDedicatedRemapTargetTablespaceDetails.
        :rtype: str
        """
        return self._remap_target

    @remap_target.setter
    def remap_target(self, remap_target):
        """
        Sets the remap_target of this CreateADBDedicatedRemapTargetTablespaceDetails.
        Name of tablespace at target to which the source database tablespace need to be remapped.


        :param remap_target: The remap_target of this CreateADBDedicatedRemapTargetTablespaceDetails.
        :type: str
        """
        self._remap_target = remap_target

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscribedServiceUser(object):
    """
    User.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SubscribedServiceUser object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SubscribedServiceUser.
        :type name: str

        :param username:
            The value to assign to the username property of this SubscribedServiceUser.
        :type username: str

        :param first_name:
            The value to assign to the first_name property of this SubscribedServiceUser.
        :type first_name: str

        :param last_name:
            The value to assign to the last_name property of this SubscribedServiceUser.
        :type last_name: str

        :param email:
            The value to assign to the email property of this SubscribedServiceUser.
        :type email: str

        :param tca_contact_id:
            The value to assign to the tca_contact_id property of this SubscribedServiceUser.
        :type tca_contact_id: int

        :param tca_cust_accnt_site_id:
            The value to assign to the tca_cust_accnt_site_id property of this SubscribedServiceUser.
        :type tca_cust_accnt_site_id: int

        :param tca_party_id:
            The value to assign to the tca_party_id property of this SubscribedServiceUser.
        :type tca_party_id: int

        """
        self.swagger_types = {
            'name': 'str',
            'username': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'email': 'str',
            'tca_contact_id': 'int',
            'tca_cust_accnt_site_id': 'int',
            'tca_party_id': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'username': 'username',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'email': 'email',
            'tca_contact_id': 'tcaContactId',
            'tca_cust_accnt_site_id': 'tcaCustAccntSiteId',
            'tca_party_id': 'tcaPartyId'
        }

        self._name = None
        self._username = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._tca_contact_id = None
        self._tca_cust_accnt_site_id = None
        self._tca_party_id = None

    @property
    def name(self):
        """
        Gets the name of this SubscribedServiceUser.
        Name.


        :return: The name of this SubscribedServiceUser.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SubscribedServiceUser.
        Name.


        :param name: The name of this SubscribedServiceUser.
        :type: str
        """
        self._name = name

    @property
    def username(self):
        """
        Gets the username of this SubscribedServiceUser.
        Username.


        :return: The username of this SubscribedServiceUser.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this SubscribedServiceUser.
        Username.


        :param username: The username of this SubscribedServiceUser.
        :type: str
        """
        self._username = username

    @property
    def first_name(self):
        """
        Gets the first_name of this SubscribedServiceUser.
        First name.


        :return: The first_name of this SubscribedServiceUser.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this SubscribedServiceUser.
        First name.


        :param first_name: The first_name of this SubscribedServiceUser.
        :type: str
        """
        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this SubscribedServiceUser.
        Last name.


        :return: The last_name of this SubscribedServiceUser.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this SubscribedServiceUser.
        Last name.


        :param last_name: The last_name of this SubscribedServiceUser.
        :type: str
        """
        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this SubscribedServiceUser.
        Email.


        :return: The email of this SubscribedServiceUser.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this SubscribedServiceUser.
        Email.


        :param email: The email of this SubscribedServiceUser.
        :type: str
        """
        self._email = email

    @property
    def tca_contact_id(self):
        """
        Gets the tca_contact_id of this SubscribedServiceUser.
        TCA contact ID.


        :return: The tca_contact_id of this SubscribedServiceUser.
        :rtype: int
        """
        return self._tca_contact_id

    @tca_contact_id.setter
    def tca_contact_id(self, tca_contact_id):
        """
        Sets the tca_contact_id of this SubscribedServiceUser.
        TCA contact ID.


        :param tca_contact_id: The tca_contact_id of this SubscribedServiceUser.
        :type: int
        """
        self._tca_contact_id = tca_contact_id

    @property
    def tca_cust_accnt_site_id(self):
        """
        Gets the tca_cust_accnt_site_id of this SubscribedServiceUser.
        TCA customer account site ID.


        :return: The tca_cust_accnt_site_id of this SubscribedServiceUser.
        :rtype: int
        """
        return self._tca_cust_accnt_site_id

    @tca_cust_accnt_site_id.setter
    def tca_cust_accnt_site_id(self, tca_cust_accnt_site_id):
        """
        Sets the tca_cust_accnt_site_id of this SubscribedServiceUser.
        TCA customer account site ID.


        :param tca_cust_accnt_site_id: The tca_cust_accnt_site_id of this SubscribedServiceUser.
        :type: int
        """
        self._tca_cust_accnt_site_id = tca_cust_accnt_site_id

    @property
    def tca_party_id(self):
        """
        Gets the tca_party_id of this SubscribedServiceUser.
        TCA party ID.


        :return: The tca_party_id of this SubscribedServiceUser.
        :rtype: int
        """
        return self._tca_party_id

    @tca_party_id.setter
    def tca_party_id(self, tca_party_id):
        """
        Sets the tca_party_id of this SubscribedServiceUser.
        TCA party ID.


        :param tca_party_id: The tca_party_id of this SubscribedServiceUser.
        :type: int
        """
        self._tca_party_id = tca_party_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .traffic_node import TrafficNode
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AccessDeniedTrafficNode(TrafficNode):
    """
    Defines the configuration of a traffic node to which the user is denied access.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AccessDeniedTrafficNode object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.AccessDeniedTrafficNode.type` attribute
        of this class is ``ACCESS_DENIED`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AccessDeniedTrafficNode.
            Allowed values for this property are: "VISIBLE", "ACCESS_DENIED"
        :type type: str

        :param egress_traffic:
            The value to assign to the egress_traffic property of this AccessDeniedTrafficNode.
        :type egress_traffic: oci.vn_monitoring.models.EgressTrafficSpec

        :param next_hop_routing_action:
            The value to assign to the next_hop_routing_action property of this AccessDeniedTrafficNode.
        :type next_hop_routing_action: oci.vn_monitoring.models.RoutingAction

        :param egress_security_action:
            The value to assign to the egress_security_action property of this AccessDeniedTrafficNode.
        :type egress_security_action: oci.vn_monitoring.models.SecurityAction

        :param ingress_security_action:
            The value to assign to the ingress_security_action property of this AccessDeniedTrafficNode.
        :type ingress_security_action: oci.vn_monitoring.models.SecurityAction

        """
        self.swagger_types = {
            'type': 'str',
            'egress_traffic': 'EgressTrafficSpec',
            'next_hop_routing_action': 'RoutingAction',
            'egress_security_action': 'SecurityAction',
            'ingress_security_action': 'SecurityAction'
        }

        self.attribute_map = {
            'type': 'type',
            'egress_traffic': 'egressTraffic',
            'next_hop_routing_action': 'nextHopRoutingAction',
            'egress_security_action': 'egressSecurityAction',
            'ingress_security_action': 'ingressSecurityAction'
        }

        self._type = None
        self._egress_traffic = None
        self._next_hop_routing_action = None
        self._egress_security_action = None
        self._ingress_security_action = None
        self._type = 'ACCESS_DENIED'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
